@@ -52,8 +52,10 @@ def show_category_pattern1(category_int):
 def show_category_pattern2(category_int):
     objects = Post.objects.filter(status=1).filter(category=category_int).order_by('-updated_on')
     return {
-        'top9': objects[:9],
-        'the_others': objects[9:15]
+        'top3': objects[:3],
+        'the_others1': objects[3:6],
+        'the_others2': objects[6:9],
+        'the_others3': objects[9:15],
     }
 
 
@@ -103,7 +105,10 @@ def show_footer():
         'latest_one': Post.objects.filter(status=1).latest('updated_on'),
         'latest': Post.objects.filter(status=1).order_by('-updated_on')[:4],
         'menu': context['menu'],
-        'clinic_link': context['clinic_link']
+        'clinic_link': context['clinic_link'],
+        'blog_name': context['blog_name'],
+        'about': context['footer']['about'],
+        'menu': context['menu'],
     }
 
 
