@@ -11,6 +11,6 @@ urlpatterns = [
     path('category/<int:category_int>', views.Category.as_view(), name='category'),
     path('search-result/', views.SearchResult.as_view(), name='search_result'),
     path('search-tag/<str:tag>', views.SearchTag.as_view(), name='search_tag'),
-    path('<slug:slug>/', views.PostDetailView.as_view(), name='post_detail'),
+    path('<slug>/', views.PostDetailView.as_view(), name='post_detail'),
     path('hitcount/', include(('hitcount.urls', 'hitcount'), namespace='hitcount')),
 ]
